#
# spec file for package icewm-theme-branding
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   icewm-config-openSUSE
%define icewm_version 1.4.2

%define flavor openSUSE
%if "%{flavor}" == ""
ExclusiveArch:  %{nil}
%else
%define branding_name %{flavor}
%if "%{flavor}" == "SLE"
%define build_SLE 1
%else
%define build_openSUSE 1
%endif
%endif

%if (0%{?build_SLE} && 0%{?is_opensuse}) || (0%{?build_openSUSE} && ! 0%{?is_opensuse})
# Don't build SLE branding on openSUSE and vice-versa
ExclusiveArch:  %{nil}
%endif

Name:           icewm-theme-branding
Version:        1.2.4
Release:        lp152.6.5.1
Summary:        Icewm theme branding for SLES or openSUSE Leap
License:        LGPL-2.1-or-later AND GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/openSUSE/icewm-config-openSUSE
Source:         https://github.com/openSUSE/%{_name}/archive/%{_name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM add-adwaita-legacy-iconpath-to-preference.patch bsc#1157930 gh#openSUSE/icewm-config-openSUSE!8 yfjiang@suse.com -- Add the adwaita legacy path to the IconPath 
Patch0:         add-adwaita-legacy-iconpath-to-preference.patch
Requires:       icewm
Conflicts:      icewm < 1.3.11
Conflicts:      otherproviders(icewm-configuration-files)
Obsoletes:      icewm-config-upstream     <= %{icewm_version}
Provides:       icewm-configuration-files = %{icewm_version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This package is made for SLE or openSUSE customization of icewm, including
the system default theme,background etc.

%prep
%setup -q -n %{_name}-%{_name}-%{version}
%patch0 -p1

%build
%if 0%{?build_openSUSE}
sed -i -e 's:SLEdefault:openSUSEdefault:g' preferences
%endif

%install
make DESTDIR=%{buildroot} prefix=%{_prefix} install
# move preferences to prefoverride to take preference over themes
mv %{buildroot}/%{_sysconfdir}/icewm/preferences \
   %{buildroot}/%{_sysconfdir}/icewm/prefoverride

%files
%defattr(-,root,root)
%doc LICENSE.GPL-2.0 LICENSE.LGPL-2.1 LICENSE.MIT
%dir %{_sysconfdir}/icewm
%config %{_sysconfdir}/icewm/keys
%config %{_sysconfdir}/icewm/menu
%config %{_sysconfdir}/icewm/prefoverride
%config %{_sysconfdir}/icewm/startup
%config %{_sysconfdir}/icewm/theme
%config %{_sysconfdir}/icewm/toolbar
%config %{_sysconfdir}/icewm/winoptions
%dir %{_datadir}/icewm/
%dir %{_datadir}/icewm/themes/
%dir %{_datadir}/icewm/themes/zpaker/
%{_datadir}/icewm/themes/zpaker/*

%changelog
* Thu Jun 11 2020 Yifan Jiang <yfjiang@suse.com>
- Improve spec:
  * Make a more explict summary since this package is not used by
    openSUSE Tumbleweed.
  * Introduce %%{icewm_version} to make the provided capability had a
    consistent version number with icewm-config-upstream.
  * Explicitly obsoletes icewm-config-upstream to fix the "zypper
    dup" issue on Leap (bsc#1170420).
* Mon Mar 16 2020 Yifan Jiang <yfjiang@suse.com>
- Improve build tag consistency between SLE and Leap
  (jsc#SLE-11888, bsc#1170420).
  * Build the branding package separately for openSUSE and SLE,
    like most of other branding packages did.
* Thu Mar  5 2020 Yifan Jiang <yfjiang@suse.com>
- Add add-adwaita-legacy-iconpath-to-preference.patch:
  Add the adwaita legacy path to the IconPath in
  preferences. adwaita-icon-theme has its main icon updated to
  symbolic style, while icewm's style is more suitable for
  legacy-style icons (eg. web-browser).  Without the update,
  current icewm can not find default web-browser toolbar icon
  (bsc#1157930).
* Mon Mar 19 2018 qzheng@suse.com
- Version update to 1.2.4
  CJK fonts issue with the zpaker theme was fixed (bsc#1077174) and
  MenuMouseTracking now enabled by default.
* Tue Oct 10 2017 tchvatal@suse.com
- Use prefoverride instead of preferences in the sysconfig to make
  sure take priority over theme
* Sat Sep 30 2017 yfjiang@suse.com
- Version update to 1.2.3
  Add xcreensaver back because of the risk brought by xlockmore's
  monolithic runtime. Some detailed were discussed in fate#323630.
* Fri Aug 26 2016 yfjiang@suse.com
- Version update to 1.2.2
  Add new startup script for icewm-session (bsc#977233)
  Fix quotation in commands in preferences (bsc#977233)
* Fri Jun  3 2016 yfjiang@suse.com
- Version update to 1.2.1
  drop xscreensaver, use only xlockmore (fate#320737)
* Wed Mar 30 2016 tchvatal@suse.com
- Conflict with older icewm to ensure clean migration path
* Wed Mar 30 2016 tchvatal@suse.com
- Version update to 1.2 and transfer to git repository contiaing all
  the content
- Use tarball instead of files in OSC
* Mon Oct 26 2015 tchvatal@suse.com
- Retweak to use config infrastructure from the default icewm package
  to not mess with post/postun/...
- Fix rpmlint warnings
- Move start.xpm to theme instead of having it as default button
* Mon Sep 22 2014 fcrozat@suse.com
- Ensure gnome-settings-daemon is started if available, will fix
  gnome-terminal appareance (bsc#872744).
* Wed Aug  6 2014 tyang@suse.com
- Get rid of files using the old SUSE spelling (bnc#889036).
* Wed Jun 11 2014 tyang@suse.com
- Add keys.new
  remove all the information about Netscape in icewm configuration
  file (bnc#873702)
* Fri Mar 21 2014 tyang@suse.com
- Add the icewm into Requires in spec file for bug #865843
* Fri Feb 14 2014 cdenicolo@suse.com
- license update: LGPL-2.1+ and GPL-3.0+
  contains GPL-3.0 code.
* Thu Feb 13 2014 tyang@suse.com
- created icewm theme branding package for SLES or openSUSE[fate #313170]
